Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HTTPCheckLister ¶
type HTTPCheckLister interface {
// List lists all HTTPChecks in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.HTTPCheck, err error)
// HTTPChecks returns an object that can list and get HTTPChecks.
HTTPChecks(namespace string) HTTPCheckNamespaceLister
HTTPCheckListerExpansion
}
HTTPCheckLister helps list HTTPChecks.
func NewHTTPCheckLister ¶
func NewHTTPCheckLister(indexer cache.Indexer) HTTPCheckLister
NewHTTPCheckLister returns a new HTTPCheckLister.
type HTTPCheckListerExpansion ¶
type HTTPCheckListerExpansion interface{}
HTTPCheckListerExpansion allows custom methods to be added to HTTPCheckLister.
type HTTPCheckNamespaceLister ¶
type HTTPCheckNamespaceLister interface {
// List lists all HTTPChecks in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.HTTPCheck, err error)
// Get retrieves the HTTPCheck from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.HTTPCheck, error)
HTTPCheckNamespaceListerExpansion
}
HTTPCheckNamespaceLister helps list and get HTTPChecks.
type HTTPCheckNamespaceListerExpansion ¶
type HTTPCheckNamespaceListerExpansion interface{}
HTTPCheckNamespaceListerExpansion allows custom methods to be added to HTTPCheckNamespaceLister.
Click to show internal directories.
Click to hide internal directories.