Documentation
¶
Index ¶
Constants ¶
const ( CheckTypeHTTP = "http" CheckTypeHTTPCustom = "httpcustom" CheckTypeTCP = "tcp" CheckTypePing = "ping" CheckTypeDNS = "dns" CheckTypeUDP = "udp" CheckTypeSMTP = "smtp" CheckTypePOP3 = "pop3" CheckTypeIMAP = "imap" )
This const block defines all the Check types that are supported by the Pingdom API TODO: currently only HTTP is supported, need to add support for all the others
const (
APIv21Checks = "/api/2.1/checks"
)
This const block defines all the Pingdom API Endpoints supported by this package
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Check ¶
type Check interface {
GetType() string
SetData(map[string]interface{}) error
SetID(int)
GetID() int
Compare(Check) bool
// contains filtered or unexported methods
}
Check allows us to work with multiple structs when working with the Pingdom API
func NewHTTPCheck ¶
NewHTTPCheck creates a HTTP Check to send to the Pingdom API
type Client ¶
Client handles sending requests to the Pingdom API
func (*Client) CreateCheck ¶
CreateCheck takes a Check struct and creates a new check against the Pingdom API
func (*Client) DeleteCheck ¶
DeleteCheck takes a Check struct and deletes the matching check in the Pingdom API
func (*Client) UpdateCheck ¶
UpdateCheck takes a Check struct and updates the matching check in the Pingdom API